'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fs = require('fs');
var resolve = require('resolve');

function startsWith(string, prefix) {
  return string.lastIndexOf(prefix, 0) === 0;
}

function babelrc() {
  var path = arguments.length <= 0 || arguments[0] === undefined ? '.babelrc' : arguments[0];

  return configWithoutModules(JSON.parse(fs.readFileSync(path, { encoding: 'utf8' })));
}

function configWithoutModules(config) {
  var result = {};

  for (var _key in config) {
    if (Object.prototype.hasOwnProperty.call(config, _key)) {
      if (_key === 'presets' && config.presets) {
        // Replace the es2015 preset with the es2015-rollup preset.
        result.presets = config.presets.map(mapPreset);
      } else if (_key === 'plugins' && config.plugins) {
        // Remove any explicit module plugins, e.g. es2015-modules-commonjs.
        result.plugins = config.plugins.filter(function (plugin) {
          return !startsWith(plugin, 'es2015-modules-');
        });
      } else {
        result[_key] = config[_key];
      }
    }
  }

  // Make sure babel does not look for the babelrc file.
  result.babelrc = false;

  return result;
}

function mapPreset(preset) {
  try {
    // this will throw if it can't resolve it
    resolve.sync('babel-preset-' + preset + '-rollup');
    return preset + '-rollup';
  } catch (err) {
    return preset;
  }
}

exports['default'] = babelrc;
exports.configWithoutModules = configWithoutModules;